# CHANGELOG



## v0.15.7 (2024-03-14)

### Fix

* fix: lib pypi hot fix ([`88d8a8b`](https://github.com/Smithed-MC/smithed-python/commit/88d8a8b68425885b66ec97c7e661b17de9c8ea52))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`5cf6778`](https://github.com/Smithed-MC/smithed-python/commit/5cf67783c33c9767279e8099681724b97d90bb06))


## v0.15.6 (2024-03-14)

### Fix

* fix: imports Update Dockerfile and pyproject.toml ([`b7c58ec`](https://github.com/Smithed-MC/smithed-python/commit/b7c58ec28e6eebf88f06403ebc914cac546a2016))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`f34a0cb`](https://github.com/Smithed-MC/smithed-python/commit/f34a0cb49c2d239b4263c6a39ab47df549cf22b9))


## v0.15.5 (2024-03-14)

### Chore

* chore: continue on error ([`82ae026`](https://github.com/Smithed-MC/smithed-python/commit/82ae02626678f682fd3b43a7be404b766a176b59))

* chore: watch Dockerfile ([`81a945d`](https://github.com/Smithed-MC/smithed-python/commit/81a945d5f4e2abc392ec933133241b192d9d8598))

* chore: disable uv ([`d5873e9`](https://github.com/Smithed-MC/smithed-python/commit/d5873e96ffca1bad5fe0b0a08b9a64669948d5d6))

* chore: Update release and deployment workflows ([`e3d6726`](https://github.com/Smithed-MC/smithed-python/commit/e3d6726f8236509c6d40a9b4d7671bc43a2801ba))

### Fix

* fix: import weld etc ([`da82576`](https://github.com/Smithed-MC/smithed-python/commit/da825763997503a232c652bc1735076cf80a5e30))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`afb7b19`](https://github.com/Smithed-MC/smithed-python/commit/afb7b190c22593c13979b9bbc989be10d9579cb2))


## v0.15.4 (2024-03-13)

### Fix

* fix: webapp improvements + docker ([`17363ba`](https://github.com/Smithed-MC/smithed-python/commit/17363ba269e8a182a3676a51a70644fbd63d3fe1))


## v0.15.3 (2024-03-13)

### Fix

* fix: Update TWINE_PASSWORD to use PYPI_TOKEN ([`10b337c`](https://github.com/Smithed-MC/smithed-python/commit/10b337c1749502d081322f82ff58cb3ad7ccfe5d))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`cd5c12e`](https://github.com/Smithed-MC/smithed-python/commit/cd5c12e71e8366e308039e3cb71184d8a99f5280))


## v0.15.2 (2024-03-13)

### Fix

* fix: update PyPI deployment configuration ([`e270fae`](https://github.com/Smithed-MC/smithed-python/commit/e270fae467000537c95848f3c802c437502dccd8))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`c3e4e08`](https://github.com/Smithed-MC/smithed-python/commit/c3e4e08409fd86dad49ff2070fa51b0e33af716e))


## v0.15.1 (2024-03-13)

### Fix

* fix: (chore) bump minor ver and clean main.yml workflow ([`b4a9a7d`](https://github.com/Smithed-MC/smithed-python/commit/b4a9a7d12844fdde39c779b69bd540a9a8f20128))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`7fadde5`](https://github.com/Smithed-MC/smithed-python/commit/7fadde52a5483fca14e9438223379e4d7b89c6cd))


## v0.15.0 (2024-03-12)

### Chore

* chore: bump GA action ([`fc3135a`](https://github.com/Smithed-MC/smithed-python/commit/fc3135a4cd8dcb1f18660afc57f6ebf7046cbd49))

* chore: use uv with rye ([`4c9891e`](https://github.com/Smithed-MC/smithed-python/commit/4c9891ef3aa20a2e679836325ddc7ebd0f20f867))

### Documentation

* docs: improve README ([`3c26036`](https://github.com/Smithed-MC/smithed-python/commit/3c2603695f983527cc02d56ff883f30b694e2da0))

* docs: add contributing instructions to README ([`c5c6663`](https://github.com/Smithed-MC/smithed-python/commit/c5c666312e10dbd4a996ac321a3849b72e8180cf))

### Feature

* feat: update to latest deps, fix bugs, renames, and more ([`c9bed77`](https://github.com/Smithed-MC/smithed-python/commit/c9bed77907e9c00fb357f05498e6988a056a77e6))

* feat: bump to 1.20.3 ([`8d9cef5`](https://github.com/Smithed-MC/smithed-python/commit/8d9cef5f60001ddefbf43937f3ad0c4f5a2b2885))

### Fix

* fix: add weld as a specific package ([`8bfde78`](https://github.com/Smithed-MC/smithed-python/commit/8bfde782566c0167fd5bde8b3d1a14525989c3d6))

* fix: version ([`2f7177c`](https://github.com/Smithed-MC/smithed-python/commit/2f7177c53c6b0375e792cd6a4529dd4e47033b17))

* fix: possible fix ([`3e7c4a3`](https://github.com/Smithed-MC/smithed-python/commit/3e7c4a32e30410f343d32aa29db1744cc081a446))

### Style

* style: paint it black ([`48523a3`](https://github.com/Smithed-MC/smithed-python/commit/48523a38ed685f2135774fe2d94020de2355a891))

### Unknown

* Add activation of virtual environment before running the script ([`ae591f0`](https://github.com/Smithed-MC/smithed-python/commit/ae591f0eadf0624cb82c974da50e16b07cffaa91))

* Update GitHub Actions workflow and Python version ([`0596c17`](https://github.com/Smithed-MC/smithed-python/commit/0596c173eb8f0be65465b6d256b3ab126879dfca))

* Update release process ([`039169f`](https://github.com/Smithed-MC/smithed-python/commit/039169f50c10567521bb7b51e00d28cc430120f9))

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`2d6495f`](https://github.com/Smithed-MC/smithed-python/commit/2d6495ffff84c85ea021ecc391c7bbe044d5fd21))

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`8d09bbe`](https://github.com/Smithed-MC/smithed-python/commit/8d09bbef82ddb65597d0884141864e11c948aa38))

* Readme tweak for windows

No windows instructions provided, the existing ones were only for Linux and Mac so I just linked the standard setup instructions until a proper guide is written out. ([`98b9571`](https://github.com/Smithed-MC/smithed-python/commit/98b957168bfd5b35aa98760e8dd0dd13e36f3641))

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`a0f3a14`](https://github.com/Smithed-MC/smithed-python/commit/a0f3a14adabed4751af328b6be2f671cb82fa14d))


## v0.14.4 (2023-11-11)

### Fix

* fix: missing f-string ([`fa75e8a`](https://github.com/Smithed-MC/smithed-python/commit/fa75e8a170c426868308f711d1b7a65e409ea624))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`fa3c8cf`](https://github.com/Smithed-MC/smithed-python/commit/fa3c8cf076fb015868db606dd8ad663518b5b007))


## v0.14.3 (2023-11-11)

### Chore

* chore: Dockerfile ([`0de483d`](https://github.com/Smithed-MC/smithed-python/commit/0de483da597ea751b113f6e410a2c3abbe62328e))

### Documentation

* docs: fixup changelog ([`8239620`](https://github.com/Smithed-MC/smithed-python/commit/8239620990dd25a890edee227262ba2b812416a8))

### Fix

* fix: improve debugging ([`1cf4808`](https://github.com/Smithed-MC/smithed-python/commit/1cf480884547e66f56475057764ff047e329c0aa))


## v0.14.2 (2023-10-15)

### Fix

* fix: bump patch ([`51822d2`](https://github.com/Smithed-MC/smithed-python/commit/51822d2901cdea5ebe9f3ac39bb39e53d15c4661))

### Unknown

* fix display error better + bump beet ver ([`604ad54`](https://github.com/Smithed-MC/smithed-python/commit/604ad549fd0ae25df6c231f833fda183b6acf4e2))


## v0.14.1 (2023-10-12)

### Fix

* fix: temporarily remove unknown_files plugin ([`6451071`](https://github.com/Smithed-MC/smithed-python/commit/6451071cffffc64c8891341a76f0ef820edc359b))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`2b9d687`](https://github.com/Smithed-MC/smithed-python/commit/2b9d687df2bb92e6e474a888489ad878fd2c95bc))


## v0.14.0 (2023-10-12)

### Feature

* feat: add overlays support and speedup for webapp ([`d56f3e1`](https://github.com/Smithed-MC/smithed-python/commit/d56f3e14d46599f09edfad13c79066f391e12770))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`51a2e79`](https://github.com/Smithed-MC/smithed-python/commit/51a2e79cf2fe2e1705dee02a2441025240da36d0))


## v0.13.4 (2023-10-12)

### Chore

* chore: fix semantic-verison downgrade ([`f94148e`](https://github.com/Smithed-MC/smithed-python/commit/f94148e55c3ad60a0e33ffd374c0f96b5335f6fd))

* chore: fix pyproject.toml ([`dd96c38`](https://github.com/Smithed-MC/smithed-python/commit/dd96c385294fa30c1a15c989b62d010d452bd7aa))

* chore: adjust CI ([`6ac1849`](https://github.com/Smithed-MC/smithed-python/commit/6ac1849d83d8b2542eb1b443e94c471345d84054))

* chore: poetry to rye

- make `smithed` imports default
- using rye updates pyproject, etc
- new ci flow ([`3ccd44f`](https://github.com/Smithed-MC/smithed-python/commit/3ccd44faf5210ac73bb86772773d19bd26a32c12))

### Fix

* fix: merge conflict ([`9c53472`](https://github.com/Smithed-MC/smithed-python/commit/9c5347260062fa2cb8d5675b4c370463f2b311ea))

### Unknown

* &#39;chore: make CI run pls&#39;g ([`93845df`](https://github.com/Smithed-MC/smithed-python/commit/93845dfe4f83a75ea32bb6904f6fe9eb32cc8b97))


## v0.13.3 (2023-09-03)

### Fix

* fix: remove 2 pack for weld, make loading packs better ([`552db97`](https://github.com/Smithed-MC/smithed-python/commit/552db97d427aea9b252db5b2235773b84c5d904b))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`f08cd71`](https://github.com/Smithed-MC/smithed-python/commit/f08cd710cb578f93657eb74f387e850e05fcac41))

* app: adjust streamlit ([`8894498`](https://github.com/Smithed-MC/smithed-python/commit/88944989efc1a93668f0a28347e566124b9bd7df))


## v0.13.2 (2023-08-31)

### Fix

* fix: adjust dependencies ([`06aa745`](https://github.com/Smithed-MC/smithed-python/commit/06aa745f5963d7b0681cef9a87a2e047980bcdf8))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`a74aa97`](https://github.com/Smithed-MC/smithed-python/commit/a74aa97d4f2c8acb794f19e949a430b1597ce071))


## v0.13.1 (2023-08-31)

### Fix

* fix: patch __init__.py ([`7d3b0ad`](https://github.com/Smithed-MC/smithed-python/commit/7d3b0ad4d5b6c8b959ced05a7ad2a547e6df1a73))


## v0.13.0 (2023-08-31)

### Chore

* chore: update deps ([`c62dabe`](https://github.com/Smithed-MC/smithed-python/commit/c62dabe628495ba7f16220c054111563a96c3425))

* chore: disable tests i guess ([`2086a49`](https://github.com/Smithed-MC/smithed-python/commit/2086a490cf6a29bca327b8abda2f8ebb895ccc14))

* chore: update .github to run tests on push ([`daa9db0`](https://github.com/Smithed-MC/smithed-python/commit/daa9db0cd7c5e244925e23f59f1b450536ad9e0d))

### Feature

* feat: neat icon there ([`3129f2b`](https://github.com/Smithed-MC/smithed-python/commit/3129f2bd52e8b7159a268eb7393a4fa5406b9867))

* feat: add override as a way to completely take over the file ([`4e86277`](https://github.com/Smithed-MC/smithed-python/commit/4e8627737b95bd789ce2ab5927de04cabcbe85cd))

* feat: add conditions, tests for stages and conditions ([`5d5ba28`](https://github.com/Smithed-MC/smithed-python/commit/5d5ba28e0f3559ab059e552355e871d6518ecc0f))

* feat: cli working, tests, and more ([`9dc9374`](https://github.com/Smithed-MC/smithed-python/commit/9dc9374867f3b017ea31a73ea7f0c38b50c2392c))

* feat: fix up weld cli and more ([`eef7bba`](https://github.com/Smithed-MC/smithed-python/commit/eef7bbaee659e839990a6154900e78f2280f3c7c))

* feat: but good ([`3f0ec52`](https://github.com/Smithed-MC/smithed-python/commit/3f0ec52d1b6559ecf57e057cdcbf629ca5dcad31))

### Fix

* fix: tests, streamlit, etc ([`0d166fb`](https://github.com/Smithed-MC/smithed-python/commit/0d166fbb6a76d8154c9553b08f4054b72a1ee12f))

* fix: update streamlit to newest weld ([`be54f60`](https://github.com/Smithed-MC/smithed-python/commit/be54f60d277078ae446194f5264ae4cd3809bc96))

* fix: use backport strenum for 3.10 ([`a2adbbe`](https://github.com/Smithed-MC/smithed-python/commit/a2adbbe266394265c5e1c2aa4bb0db6170fc22ea))

* fix: secure rules, add tests ([`1f8f0ef`](https://github.com/Smithed-MC/smithed-python/commit/1f8f0efe41d038bf478bb1221618cbfc0f60871b))

### Unknown

* Merge pull request #2 from Smithed-MC/feat/weld-but-good

The Weld Overhaul
- Most of `weld` has been refactored / rewritten
- Merge policies now properly tested and turned on
- Refreshed webapp to make it more stable
- Introduced a stable CLI for use (and pretty)
- Cleaned up `run_weld` a bit ([`a54470f`](https://github.com/Smithed-MC/smithed-python/commit/a54470fc03098679bb5480e5b8217a87a10cead3))


## v0.12.0 (2023-07-07)

### Feature

* feat: add manual streamlit option `streamlit run app/main.py` ([`6fc26f9`](https://github.com/Smithed-MC/smithed-python/commit/6fc26f9d301018312d0dc3f7695a9f558c70ba27))

### Fix

* fix: bump ver ([`e19f1d5`](https://github.com/Smithed-MC/smithed-python/commit/e19f1d564b085379cee7b64f65e428ecd3f960ef))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`3edc787`](https://github.com/Smithed-MC/smithed-python/commit/3edc78720d3693d748681d353430979018805cd6))


## v0.11.2 (2023-06-13)

### Fix

* fix: update deps, include explicit model merging ([`2312515`](https://github.com/Smithed-MC/smithed-python/commit/23125157be27cadc6a335c21a9379d9cab99e1f0))

* fix: update stlite to latest ([`f8b2d1a`](https://github.com/Smithed-MC/smithed-python/commit/f8b2d1a19a13ccfa935711fd1a22d7ea8a6be95d))

* fix: add altair as weld app dep ([`ef2bf45`](https://github.com/Smithed-MC/smithed-python/commit/ef2bf45500c630f6e9805d999f2c0f1a4f8ed6d9))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`6cca2ea`](https://github.com/Smithed-MC/smithed-python/commit/6cca2ea8cc2c603d848425e8fb95ed3306ebac00))


## v0.11.1 (2023-04-25)

### Fix

* fix: bump mecha, bolt ([`44adc8b`](https://github.com/Smithed-MC/smithed-python/commit/44adc8b5c58fd147abd4011154c28a93dae9688d))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`9ca13d4`](https://github.com/Smithed-MC/smithed-python/commit/9ca13d4e93ea515b0dcce883027189b1c62b1df9))


## v0.11.0 (2023-04-25)

### Feature

* feat: upgrade `beet` and add `unknown_files` plugin ([`8ceb8c6`](https://github.com/Smithed-MC/smithed-python/commit/8ceb8c6db2ad3828e0a86c2c14490639bfc21ae0))

### Test

* test: update pack versions ([`302e91b`](https://github.com/Smithed-MC/smithed-python/commit/302e91b667ed0dc59919562f0ca2c4139e3631e7))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`1304a3c`](https://github.com/Smithed-MC/smithed-python/commit/1304a3ce81e00652ae287ecd3ff03c30b7b96a8a))


## v0.10.0 (2023-04-24)

### Feature

* feat: adjust for newest snapshot ([`d4778de`](https://github.com/Smithed-MC/smithed-python/commit/d4778de31526f6b4f56bbe3818ae9362bbf8dac9))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`6f990c4`](https://github.com/Smithed-MC/smithed-python/commit/6f990c45c039386d16e72a7b39a091443b475c0f))


## v0.9.3 (2023-03-27)

### Fix

* fix: force release ([`1829d6d`](https://github.com/Smithed-MC/smithed-python/commit/1829d6dd2cd0d43aadfafcad7aeca2cace64f981))

* fix: disable tests for now on CI ([`24bbd16`](https://github.com/Smithed-MC/smithed-python/commit/24bbd1648690927c5bf3a05d5e5f1b18f85dff07))

* fix: full test verbosity ([`80c1293`](https://github.com/Smithed-MC/smithed-python/commit/80c1293a71d41ad54ef6ffb3dcddba845ae2d437))

* fix: update beet and deps + add github action ([`11ab749`](https://github.com/Smithed-MC/smithed-python/commit/11ab7493166b8c5fa92574466d89e3aec9cc60af))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/Smithed-MC/smithed-python ([`1e14561`](https://github.com/Smithed-MC/smithed-python/commit/1e14561b5b45247cd3104e4ead17bba89cd53961))


## v0.9.2 (2023-02-15)

### Fix

* fix: disable latest snapshot if it fails ([`c72432f`](https://github.com/Smithed-MC/smithed-python/commit/c72432fcf83e0cf3aa4beb55356bdbeb21cda823))


## v0.9.1 (2023-02-02)


## v0.9.0 (2023-02-02)

### Fix

* fix: add versioning to weld ([`8372224`](https://github.com/Smithed-MC/smithed-python/commit/8372224d38a74d13c99027c49910d2051997c15d))

* fix: use correct package ([`a82f18c`](https://github.com/Smithed-MC/smithed-python/commit/a82f18cb57aaf9c3807e5fc8dcd47fad61f511ce))


## v0.8.0 (2023-02-02)

### Feature

* feat: add atlas support ([`35355f3`](https://github.com/Smithed-MC/smithed-python/commit/35355f314162991ee1584ba0279c7ad3b8174e1e))


## v0.7.2 (2023-01-09)

### Fix

* fix: app not reloading ([`16c1b4d`](https://github.com/Smithed-MC/smithed-python/commit/16c1b4d660cb68fd3397e79c9f67ea89623585b0))

* fix: mistake with app/index.html ([`69e9a92`](https://github.com/Smithed-MC/smithed-python/commit/69e9a92b0710a2ad4cfb466e514ebe9f30eb155a))


## v0.7.1 (2023-01-09)


## v0.7.0 (2023-01-09)

### Feature

* feat: move app source to `weld` package ([`f59da76`](https://github.com/Smithed-MC/smithed-python/commit/f59da7613ac2c89e72753152e82edcd853097eb5))


## v0.6.1 (2023-01-09)


## v0.6.0 (2023-01-09)

### Feature

* feat: fix bug ([`c27732a`](https://github.com/Smithed-MC/smithed-python/commit/c27732a84d02a720ad34ee3decc2cfe189b7f322))


## v0.5.0 (2023-01-09)

### Feature

* feat: implement experiemental fabric output feature ([`403052e`](https://github.com/Smithed-MC/smithed-python/commit/403052ee8669de9c1503d4e6e64f7e86caee59cc))

* feat: add experimental fabric jar download ([`d23846c`](https://github.com/Smithed-MC/smithed-python/commit/d23846cebf6583dd4a5ee6f559b515a7fd6976d0))

* feat: improve app to use smithed and intents ([`6e17188`](https://github.com/Smithed-MC/smithed-python/commit/6e171880f969bede7846d72ecab181c574782cf9))

### Fix

* fix: hosted app ([`9dce4a8`](https://github.com/Smithed-MC/smithed-python/commit/9dce4a893da3598496c269eda3d59cda7b893ddb))

### Unknown

* Create static.yml ([`348e420`](https://github.com/Smithed-MC/smithed-python/commit/348e420feb04171eea611ebfa52b959b72314e89))


## v0.4.0 (2023-01-08)


## v0.3.0 (2023-01-08)

### Feature

* feat: redid everything ([`92dc2db`](https://github.com/Smithed-MC/smithed-python/commit/92dc2db7f98598246addb8f33cbed6754eb96fea))


## v0.2.0 (2022-12-14)


## v0.1.0 (2022-12-14)

### Feature

* feat(weld): first version of weld ([`6a9d2bd`](https://github.com/Smithed-MC/smithed-python/commit/6a9d2bd09bc35655da6a475bd9d0464aec1a9260))

### Unknown

* Initial commit ([`203eef3`](https://github.com/Smithed-MC/smithed-python/commit/203eef384512b2167945d5c15c1133e7281e716f))
